public inbox for igt-dev@lists.freedesktop.org
 help / color / mirror / Atom feed
* [PATCH i-g-t v1] tests/kms_content_protection: Split dp-mst-suspend-resume tests
@ 2026-01-07  5:11 Santhosh Reddy Guddati
  2026-01-07  6:25 ` ✓ Xe.CI.BAT: success for " Patchwork
                   ` (4 more replies)
  0 siblings, 5 replies; 6+ messages in thread
From: Santhosh Reddy Guddati @ 2026-01-07  5:11 UTC (permalink / raw)
  To: igt-dev; +Cc: karthik.b.s, mohammed.thasleem, Santhosh Reddy Guddati

Split the dp-mst hdcp suspend resume tests to work on sinks that
supports only HDCP 1.4 as dp-mst-type-0.

For HDCP 2.2 specific, add a new subtest dp-mst-type-1-suspend-resume.
These changes allow testing s/r on DP mst configs regardless of sink's
HDCP version.

Signed-off-by: Santhosh Reddy Guddati <santhosh.reddy.guddati@intel.com>
---
 tests/kms_content_protection.c | 10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)

diff --git a/tests/kms_content_protection.c b/tests/kms_content_protection.c
index 377bab9a3..7c459978b 100644
--- a/tests/kms_content_protection.c
+++ b/tests/kms_content_protection.c
@@ -87,7 +87,8 @@
  * @lic-type-1:   Type 1 with LIC.
  * @type-0:       Type 0
  * @type-1:       Type 1
  * @suspend-resume: Suspend and resume the system
  */
 
 IGT_TEST_DESCRIPTION("Test content protection (HDCP)");
@@ -1011,8 +1012,13 @@ static const struct {
 	  .cp_tests = CP_LIC,
 	  .content_type = HDCP_CONTENT_TYPE_1,
 	},
+	{ .desc = "Test Content protection(Type 0) over DP MST with suspend resume.",
+	  .name = "dp-mst-type-0-suspend-resume",
+	  .cp_tests = SUSPEND_RESUME,
+	  .content_type = HDCP_CONTENT_TYPE_0,
+	},
 	{ .desc = "Test Content protection(Type 1) over DP MST with suspend resume.",
-	  .name = "dp-mst-suspend-resume",
+	  .name = "dp-mst-type-1-suspend-resume",
 	  .cp_tests = SUSPEND_RESUME,
 	  .content_type = HDCP_CONTENT_TYPE_1,
 	},
@@ -87,7 +87,8 @@
  * @type-0:       Type 0
  * @type-1:       Type 1
- * @suspend-resume: Suspend and resume the system
+ * @type-0-suspend-resume: Type 0 with suspend and resume the system
+ * @type-1-suspend-resume: Type 1 with suspend and resume the system
  */
 
-- 
2.34.1


^ permalink raw reply related	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2026-01-07  9:15 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2026-01-07  5:11 [PATCH i-g-t v1] tests/kms_content_protection: Split dp-mst-suspend-resume tests Santhosh Reddy Guddati
2026-01-07  6:25 ` ✓ Xe.CI.BAT: success for " Patchwork
2026-01-07  6:31 ` ✓ i915.CI.BAT: " Patchwork
2026-01-07  7:49 ` ✗ Xe.CI.Full: failure " Patchwork
2026-01-07  8:57 ` ✗ i915.CI.Full: " Patchwork
2026-01-07  9:14 ` [PATCH i-g-t v1] " Thasleem, Mohammed

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox